#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 slist
version:              0.2.1.0
visibility:           public
id:                   slist-0.2.1.0-2j4MFfMB3AA8HiB5yV7RbX
key:                  slist-0.2.1.0-2j4MFfMB3AA8HiB5yV7RbX
license:              MPL-2.0
copyright:
    2019-2020 Veronika Romashkina
    2020-2022 Kowainik

maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina
homepage:             https://github.com/kowainik/slist
synopsis:             Sized list
description:
    This package implements @Slist@ data structure that stores the size
    of the list along with the list itself.

category:             Data Structures, List
abi:                  db0699cbcfd8ad87ac41bca22737c40b
exposed:              True
exposed-modules:
    Slist Slist.Containers Slist.Maybe Slist.Size Slist.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/slist-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/slist-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/slist-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-slist
hs-libraries:         HSslist-0.2.1.0-2j4MFfMB3AA8HiB5yV7RbX
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-slist/html/slist.haddock
haddock-html:         /usr/share/doc/haskell-slist/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

